@@ -23,7 +23,7 @@ LOG = logging.getLogger(__name__)
 
 
 def get_composer(catalog):
-    return plugin_util.get_module('orquesta.composers', catalog)
+    return plugin_util.get_module("orquesta.composers", catalog)
 
 
 @six.add_metaclass(abc.ABCMeta)
