@@ -35,28 +35,25 @@ class ExpressionEvaluatorTest(unittest.TestCase):
 
     @classmethod
     def setUpClass(cls):
-        cls.evaluator = plugin_util.get_module('orquesta.expressions.evaluators', cls.language)
+        cls.evaluator = plugin_util.get_module("orquesta.expressions.evaluators", cls.language)
 
 
 @six.add_metaclass(abc.ABCMeta)
 class ExpressionFacadeEvaluatorTest(unittest.TestCase):
-
     def validate(self, expr):
-        return expr_base.validate(expr).get('errors', [])
+        return expr_base.validate(expr).get("errors", [])
 
 
 @six.add_metaclass(abc.ABCMeta)
 class WorkflowGraphTest(unittest.TestCase):
-
     def _zip_wf_graph_meta(self, wf_graph_json):
-        wf_graph_json['adjacency'] = [
-            sorted(link, key=lambda x: x['id']) if link else link
-            for link in wf_graph_json['adjacency']
+        wf_graph_json["adjacency"] = [
+            sorted(link, key=lambda x: x["id"]) if link else link
+            for link in wf_graph_json["adjacency"]
         ]
 
         wf_graph_meta = sorted(
-            zip(wf_graph_json['nodes'], wf_graph_json['adjacency']),
-            key=lambda x: x[0]['id']
+            zip(wf_graph_json["nodes"], wf_graph_json["adjacency"]), key=lambda x: x[0]["id"]
         )
 
         return wf_graph_meta
@@ -68,27 +65,25 @@ class WorkflowGraphTest(unittest.TestCase):
 
         self.assertListEqual(wf_graph_meta, expected_wf_graph_meta)
 
-        wf_graph_attrs = sorted(wf_graph_json['graph'], key=lambda x: x[0])
-        expected_wf_graph_attrs = sorted(expected_wf_graph['graph'], key=lambda x: x[0])
+        wf_graph_attrs = sorted(wf_graph_json["graph"], key=lambda x: x[0])
+        expected_wf_graph_attrs = sorted(expected_wf_graph["graph"], key=lambda x: x[0])
 
         self.assertListEqual(wf_graph_attrs, expected_wf_graph_attrs)
 
 
 class WorkflowSpecTest(unittest.TestCase):
-    spec_module_name = 'mock'
+    spec_module_name = "mock"
 
     def __init__(self, *args, **kwargs):
         super(WorkflowSpecTest, self).__init__(*args, **kwargs)
         self.maxDiff = None
 
     def get_fixture_path(self, wf_name):
-        return self.spec_module_name + '/' + wf_name + '.yaml'
+        return self.spec_module_name + "/" + wf_name + ".yaml"
 
     def get_wf_def(self, wf_name, raw=False):
         return fixture_loader.get_fixture_content(
-            self.get_fixture_path(wf_name),
-            'workflows',
-            raw=raw
+            self.get_fixture_path(wf_name), "workflows", raw=raw
         )
 
     def get_wf_spec(self, wf_name):
@@ -114,7 +109,7 @@ class WorkflowComposerTest(WorkflowGraphTest, WorkflowSpecTest):
         WorkflowGraphTest.setUpClass()
         WorkflowSpecTest.setUpClass()
 
-        cls.composer = plugin_util.get_module('orquesta.composers', cls.spec_module_name)
+        cls.composer = plugin_util.get_module("orquesta.composers", cls.spec_module_name)
         cls.spec_module = spec_loader.get_spec_module(cls.spec_module_name)
         cls.wf_spec_type = cls.spec_module.WorkflowSpec
 
@@ -143,27 +138,29 @@ class WorkflowComposerTest(WorkflowGraphTest, WorkflowSpecTest):
 
 @six.add_metaclass(abc.ABCMeta)
 class WorkflowConductorTest(WorkflowComposerTest):
-
-    def format_task_item(self, task_id, route, ctx, spec, actions=None, delay=None,
-                         items_count=None, items_concurrency=None):
+    def format_task_item(
+        self,
+        task_id,
+        route,
+        ctx,
+        spec,
+        actions=None,
+        delay=None,
+        items_count=None,
+        items_concurrency=None,
+    ):
 
         if not actions and items_count is None:
-            actions = [{'action': spec.action, 'input': spec.input}]
+            actions = [{"action": spec.action, "input": spec.input}]
 
-        task = {
-            'id': task_id,
-            'route': route,
-            'ctx': ctx,
-            'spec': spec,
-            'actions': actions or []
-        }
+        task = {"id": task_id, "route": route, "ctx": ctx, "spec": spec, "actions": actions or []}
 
         if delay:
-            task['delay'] = delay
+            task["delay"] = delay
 
         if items_count is not None:
-            task['items_count'] = items_count
-            task['concurrency'] = items_concurrency
+            task["items_count"] = items_count
+            task["concurrency"] = items_concurrency
 
         return task
 
@@ -176,8 +173,16 @@ class WorkflowConductorTest(WorkflowComposerTest):
 
             conductor.update_task_state(task_id, route, ac_ex_event)
 
-    def forward_task_item_statuses(self, conductor, task_id, item_id, status_changes,
-                                   route=0, result=None, accumulated_result=None):
+    def forward_task_item_statuses(
+        self,
+        conductor,
+        task_id,
+        item_id,
+        status_changes,
+        route=0,
+        result=None,
+        accumulated_result=None,
+    ):
         for status in status_changes:
             ac_ex_event = events.TaskItemActionExecutionEvent(item_id, status)
 
@@ -198,21 +203,21 @@ class WorkflowConductorTest(WorkflowComposerTest):
         expected_copy = copy.deepcopy(expected)
 
         for task in actual_copy:
-            for staged_task in task['ctx']['__state']['staged']:
-                if 'items' in staged_task:
-                    del staged_task['items']
+            for staged_task in task["ctx"]["__state"]["staged"]:
+                if "items" in staged_task:
+                    del staged_task["items"]
 
-            task['spec'] = task['spec'].serialize()
+            task["spec"] = task["spec"].serialize()
 
         for task in expected_copy:
-            task['ctx']['__current_task'] = {'id': task['id'], 'route': task['route']}
-            task['ctx']['__state'] = conductor.workflow_state.serialize()
+            task["ctx"]["__current_task"] = {"id": task["id"], "route": task["route"]}
+            task["ctx"]["__state"] = conductor.workflow_state.serialize()
 
-            for staged_task in task['ctx']['__state']['staged']:
-                if 'items' in staged_task:
-                    del staged_task['items']
+            for staged_task in task["ctx"]["__state"]["staged"]:
+                if "items" in staged_task:
+                    del staged_task["items"]
 
-            task['spec'] = task['spec'].serialize()
+            task["spec"] = task["spec"].serialize()
 
         self.assertListEqual(actual_copy, expected_copy)
 
@@ -234,10 +239,18 @@ class WorkflowConductorTest(WorkflowComposerTest):
 
         self.assert_task_list(conductor, conductor.get_next_tasks(), expected_tasks)
 
-    def assert_conducting_sequences(self, wf_name, expected_task_seq, expected_routes=None,
-                                    inputs=None, mock_statuses=None, mock_results=None,
-                                    expected_workflow_status=None, expected_output=None,
-                                    expected_term_tasks=None):
+    def assert_conducting_sequences(
+        self,
+        wf_name,
+        expected_task_seq,
+        expected_routes=None,
+        inputs=None,
+        mock_statuses=None,
+        mock_results=None,
+        expected_workflow_status=None,
+        expected_output=None,
+        expected_term_tasks=None,
+    ):
 
         if not expected_routes:
             expected_routes = [[]]
@@ -277,8 +290,8 @@ class WorkflowConductorTest(WorkflowComposerTest):
             # Process all the tasks in the run queue.
             while not run_q.empty():
                 current_task = run_q.get()
-                current_task_id = current_task['id']
-                current_task_route = current_task['route']
+                current_task_id = current_task["id"]
+                current_task_route = current_task["route"]
 
                 # Set task status to running.
                 ac_ex_event = events.ActionExecutionEvent(statuses.RUNNING)
@@ -299,8 +312,7 @@ class WorkflowConductorTest(WorkflowComposerTest):
             wf_conducting_state = conductor.serialize()
 
         actual_task_seq = [
-            (entry['id'], entry['route'])
-            for entry in conductor.workflow_state.sequence
+            (entry["id"], entry["route"]) for entry in conductor.workflow_state.sequence
         ]
 
         expected_task_seq = [
@@ -324,12 +336,11 @@ class WorkflowConductorTest(WorkflowComposerTest):
 
         if expected_term_tasks:
             expected_term_tasks = [
-                (task, 0) if not isinstance(task, tuple) else task
-                for task in expected_term_tasks
+                (task, 0) if not isinstance(task, tuple) else task for task in expected_term_tasks
             ]
 
             term_tasks = conductor.workflow_state.get_terminal_tasks()
-            actual_term_tasks = [(t['id'], t['route']) for i, t in term_tasks]
+            actual_term_tasks = [(t["id"], t["route"]) for i, t in term_tasks]
             expected_term_tasks = sorted(expected_term_tasks, key=lambda x: x[0])
             actual_term_tasks = sorted(actual_term_tasks, key=lambda x: x[0])
             self.assertListEqual(actual_term_tasks, expected_term_tasks)
@@ -344,15 +355,15 @@ class WorkflowConductorTest(WorkflowComposerTest):
             conductor.request_workflow_status(statuses.RUNNING)
 
         for _entry, expected_wf_status in zip(mock_flow, expected_wf_statuses):
-            task_id = _entry['id']
-            task_status = _entry['status']
+            task_id = _entry["id"]
+            task_status = _entry["status"]
 
             self.forward_task_statuses(conductor, task_id, [task_status])
 
             err_ctx = (
                 'Workflow status "%s" is not the expected status "%s". '
-                'Updated task "%s" with status "%s".' %
-                (conductor.get_workflow_status(), expected_wf_status, task_id, task_status)
+                'Updated task "%s" with status "%s".'
+                % (conductor.get_workflow_status(), expected_wf_status, task_id, task_status)
             )
 
             self.assertEqual(conductor.get_workflow_status(), expected_wf_status, err_ctx)
@@ -361,10 +372,20 @@ class WorkflowConductorTest(WorkflowComposerTest):
 
 
 class WorkflowConductorWithItemsTest(WorkflowConductorTest):
-
-    def assert_task_items(self, conductor, task_id, task_route, task_ctx, items, action_specs,
-                          mock_ac_ex_statuses, expected_task_statuses, expected_workflow_statuses,
-                          concurrency=None, mock_ac_ex_results=None):
+    def assert_task_items(
+        self,
+        conductor,
+        task_id,
+        task_route,
+        task_ctx,
+        items,
+        action_specs,
+        mock_ac_ex_statuses,
+        expected_task_statuses,
+        expected_workflow_statuses,
+        concurrency=None,
+        mock_ac_ex_results=None,
+    ):
 
         # Set up test cases.
         tests = list(zip(mock_ac_ex_statuses, expected_task_statuses, expected_workflow_statuses))
@@ -381,7 +402,7 @@ class WorkflowConductorWithItemsTest(WorkflowConductorTest):
             conductor.spec.tasks.get_task(task_id),
             actions=action_specs[0:concurrency],
             items_count=len(items),
-            items_concurrency=concurrency
+            items_concurrency=concurrency,
         )
 
         expected_tasks = [expected_task]
@@ -409,7 +430,7 @@ class WorkflowConductorWithItemsTest(WorkflowConductorTest):
             capacity = concurrency - items_running
 
         if capacity > 0 and next_item_id < len(items):
-            next_action_specs = action_specs[next_item_id:next_item_id + capacity]
+            next_action_specs = action_specs[next_item_id : next_item_id + capacity]
 
         if next_action_specs or len(items) == 0:
             expected_task = self.format_task_item(
@@ -419,7 +440,7 @@ class WorkflowConductorWithItemsTest(WorkflowConductorTest):
                 conductor.spec.tasks.get_task(task_id),
                 actions=next_action_specs,
                 items_count=len(items),
-                items_concurrency=concurrency
+                items_concurrency=concurrency,
             )
 
             expected_tasks = [expected_task]
@@ -439,20 +460,18 @@ class WorkflowConductorWithItemsTest(WorkflowConductorTest):
             ac_ex_status = tests[item_id][0]
 
             ac_ex_event = events.TaskItemActionExecutionEvent(
-                item_id,
-                ac_ex_status,
-                ac_ex_result,
-                accumulated_result=tk_ex_result
+                item_id, ac_ex_status, ac_ex_result, accumulated_result=tk_ex_result
             )
 
             conductor.update_task_state(task_id, task_route, ac_ex_event)
 
             expected_task_status = tests[item_id][1]
-            actual_task_status = conductor.get_task_state_entry(task_id, task_route)['status']
+            actual_task_status = conductor.get_task_state_entry(task_id, task_route)["status"]
 
-            error_message = (
-                'Task execution status "%s" does not match "%s" for item %s.' %
-                (actual_task_status, expected_task_status, item_id)
+            error_message = 'Task execution status "%s" does not match "%s" for item %s.' % (
+                actual_task_status,
+                expected_task_status,
+                item_id,
             )
 
             self.assertEqual(actual_task_status, expected_task_status, error_message)
@@ -461,8 +480,8 @@ class WorkflowConductorWithItemsTest(WorkflowConductorTest):
             actual_workflow_status = conductor.get_workflow_status()
 
             error_message = (
-                'Workflow execution status "%s" does not match "%s" after item %s update.' %
-                (actual_workflow_status, expected_workflow_status, item_id)
+                'Workflow execution status "%s" does not match "%s" after item %s update.'
+                % (actual_workflow_status, expected_workflow_status, item_id)
             )
 
             self.assertEqual(actual_workflow_status, expected_workflow_status, error_message)
@@ -480,9 +499,9 @@ class WorkflowConductorWithItemsTest(WorkflowConductorTest):
                     task_route,
                     task_ctx,
                     conductor.spec.tasks.get_task(task_id),
-                    actions=action_specs[next_item_id:next_item_id + 1],
+                    actions=action_specs[next_item_id : next_item_id + 1],
                     items_count=len(items),
-                    items_concurrency=concurrency
+                    items_concurrency=concurrency,
                 )
 
                 expected_tasks = [expected_task]
@@ -491,20 +510,27 @@ class WorkflowConductorWithItemsTest(WorkflowConductorTest):
             self.assert_task_list(conductor, actual_tasks, expected_tasks)
 
             for task in actual_tasks:
-                task_id = task['id']
+                task_id = task["id"]
 
-                for action in task['actions']:
-                    item_id = action['item_id']
+                for action in task["actions"]:
+                    item_id = action["item_id"]
                     ac_ex_event = events.TaskItemActionExecutionEvent(item_id, statuses.RUNNING)
                     conductor.update_task_state(task_id, task_route, ac_ex_event)
 
 
 class WorkflowConductorRerunTest(WorkflowConductorTest):
-
-    def assert_rerun_failed_tasks(self, conductor, expected_task_seq, expected_routes=None,
-                                  rerun_tasks=None, mock_statuses=None, mock_results=None,
-                                  expected_workflow_status=None, expected_output=None,
-                                  expected_term_tasks=None):
+    def assert_rerun_failed_tasks(
+        self,
+        conductor,
+        expected_task_seq,
+        expected_routes=None,
+        rerun_tasks=None,
+        mock_statuses=None,
+        mock_results=None,
+        expected_workflow_status=None,
+        expected_output=None,
+        expected_term_tasks=None,
+    ):
         # Setup the test.
         run_q = queue.Queue()
         status_q = queue.Queue()
@@ -540,8 +566,8 @@ class WorkflowConductorRerunTest(WorkflowConductorTest):
             # Process all the tasks in the run queue.
             while not run_q.empty():
                 current_task = run_q.get()
-                current_task_id = current_task['id']
-                current_task_route = current_task['route']
+                current_task_id = current_task["id"]
+                current_task_route = current_task["route"]
 
                 # Set task status to running.
                 ac_ex_event = events.ActionExecutionEvent(statuses.RUNNING)
@@ -562,8 +588,7 @@ class WorkflowConductorRerunTest(WorkflowConductorTest):
             wf_conducting_state = conductor.serialize()
 
         actual_task_seq = [
-            (entry['id'], entry['route'])
-            for entry in conductor.workflow_state.sequence
+            (entry["id"], entry["route"]) for entry in conductor.workflow_state.sequence
         ]
 
         expected_task_seq = [
@@ -587,12 +612,11 @@ class WorkflowConductorRerunTest(WorkflowConductorTest):
 
         if expected_term_tasks:
             expected_term_tasks = [
-                (task, 0) if not isinstance(task, tuple) else task
-                for task in expected_term_tasks
+                (task, 0) if not isinstance(task, tuple) else task for task in expected_term_tasks
             ]
 
             term_tasks = conductor.workflow_state.get_terminal_tasks()
-            actual_term_tasks = [(t['id'], t['route']) for i, t in term_tasks]
+            actual_term_tasks = [(t["id"], t["route"]) for i, t in term_tasks]
             expected_term_tasks = sorted(expected_term_tasks, key=lambda x: x[0])
             actual_term_tasks = sorted(actual_term_tasks, key=lambda x: x[0])
             self.assertListEqual(actual_term_tasks, expected_term_tasks)
