@@ -20,7 +20,6 @@ from orquesta.tests.unit import base as test_base
 
 
 class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
-
     def test_workflow_input_error(self):
         wf_def = """
         version: 1.0
@@ -35,12 +34,12 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% result().foobar %>\'. ExpressionEvaluationException: '
-                    'The current task is not set in the context.'
-                )
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% result().foobar %>'. ExpressionEvaluationException: "
+                    "The current task is not set in the context."
+                ),
             }
         ]
 
@@ -50,9 +49,7 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
         conductor = conducting.WorkflowConductor(spec)
 
         self.assertRaises(
-            exc.InvalidWorkflowStatusTransition,
-            conductor.request_workflow_status,
-            statuses.RUNNING
+            exc.InvalidWorkflowStatusTransition, conductor.request_workflow_status, statuses.RUNNING
         )
 
         self.assertListEqual(conductor.get_next_tasks(), [])
@@ -75,12 +72,12 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().y.value %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().y.value %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#value"'
-                )
+                ),
             }
         ]
 
@@ -90,9 +87,7 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
         conductor = conducting.WorkflowConductor(spec)
 
         self.assertRaises(
-            exc.InvalidWorkflowStatusTransition,
-            conductor.request_workflow_status,
-            statuses.RUNNING
+            exc.InvalidWorkflowStatusTransition, conductor.request_workflow_status, statuses.RUNNING
         )
 
         self.assert_next_task(conductor, has_next_task=False)
@@ -113,12 +108,12 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% result().foobar %>\'. ExpressionEvaluationException: '
-                    'The current task is not set in the context.'
-                )
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% result().foobar %>'. ExpressionEvaluationException: "
+                    "The current task is not set in the context."
+                ),
             }
         ]
 
@@ -128,9 +123,7 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
         conductor = conducting.WorkflowConductor(spec)
 
         self.assertRaises(
-            exc.InvalidWorkflowStatusTransition,
-            conductor.request_workflow_status,
-            statuses.RUNNING
+            exc.InvalidWorkflowStatusTransition, conductor.request_workflow_status, statuses.RUNNING
         )
 
         self.assert_next_task(conductor, has_next_task=False)
@@ -153,12 +146,12 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().y.value %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().y.value %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#value"'
-                )
+                ),
             }
         ]
 
@@ -168,9 +161,7 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
         conductor = conducting.WorkflowConductor(spec)
 
         self.assertRaises(
-            exc.InvalidWorkflowStatusTransition,
-            conductor.request_workflow_status,
-            statuses.RUNNING
+            exc.InvalidWorkflowStatusTransition, conductor.request_workflow_status, statuses.RUNNING
         )
 
         self.assert_next_task(conductor, has_next_task=False)
@@ -210,15 +201,15 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().foobar.fubar %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().foobar.fubar %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#fubar"'
                 ),
-                'route': 0,
-                'task_id': 'task1',
-                'task_transition_id': 'task2__t0'
+                "route": 0,
+                "task_id": "task1",
+                "task_transition_id": "task2__t0",
             }
         ]
 
@@ -229,15 +220,15 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
         conductor.request_workflow_status(statuses.RUNNING)
 
         # The workflow should fail on completion of task1 while evaluating task transition.
-        self.forward_task_statuses(conductor, 'task1', [statuses.RUNNING, statuses.SUCCEEDED])
+        self.forward_task_statuses(conductor, "task1", [statuses.RUNNING, statuses.SUCCEEDED])
 
         # The workflow should fail with the expected errors.
         self.assertEqual(conductor.get_workflow_status(), statuses.FAILED)
-        actual_errors = sorted(conductor.errors, key=lambda x: x.get('task_id', None))
+        actual_errors = sorted(conductor.errors, key=lambda x: x.get("task_id", None))
         self.assertListEqual(actual_errors, expected_errors)
 
         # There are two transitions in task1. The transition to task3 should be processed.
-        staged_tasks = list(filter(lambda x: x['id'] == 'task3', conductor.workflow_state.staged))
+        staged_tasks = list(filter(lambda x: x["id"] == "task3", conductor.workflow_state.staged))
         self.assertGreater(len(staged_tasks), 0)
 
         # Since the workflow failed, there should be no next tasks returned.
@@ -275,27 +266,27 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().foobar.fubar %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().foobar.fubar %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#fubar"'
                 ),
-                'route': 0,
-                'task_id': 'task1',
-                'task_transition_id': 'task3__t0'
+                "route": 0,
+                "task_id": "task1",
+                "task_transition_id": "task3__t0",
             },
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().fubar.foobar %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().fubar.foobar %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#foobar"'
                 ),
-                'route': 0,
-                'task_id': 'task2',
-                'task_transition_id': 'task3__t0'
-            }
+                "route": 0,
+                "task_id": "task2",
+                "task_transition_id": "task3__t0",
+            },
         ]
 
         spec = native_specs.WorkflowSpec(wf_def)
@@ -306,16 +297,16 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         # Manually complete task1 and task2. Although the workflow failed when
         # processing task1, task flow can still be updated for task2.
-        self.forward_task_statuses(conductor, 'task1', [statuses.RUNNING, statuses.SUCCEEDED])
-        self.forward_task_statuses(conductor, 'task2', [statuses.RUNNING, statuses.SUCCEEDED])
+        self.forward_task_statuses(conductor, "task1", [statuses.RUNNING, statuses.SUCCEEDED])
+        self.forward_task_statuses(conductor, "task2", [statuses.RUNNING, statuses.SUCCEEDED])
 
         # The workflow should fail with the expected errors.
         self.assertEqual(conductor.get_workflow_status(), statuses.FAILED)
-        actual_errors = sorted(conductor.errors, key=lambda x: x.get('task_id', None))
+        actual_errors = sorted(conductor.errors, key=lambda x: x.get("task_id", None))
         self.assertListEqual(actual_errors, expected_errors)
 
         # Since both tasks fail evaluating task transition, task3 should not be staged.
-        self.assertNotIn('task3', conductor.workflow_state.staged)
+        self.assertNotIn("task3", conductor.workflow_state.staged)
 
         # Since the workflow failed, there should be no next tasks returned.
         self.assert_next_task(conductor, has_next_task=False)
@@ -347,15 +338,15 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().foobar.fubar %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().foobar.fubar %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#fubar"'
                 ),
-                'route': 0,
-                'task_id': 'task1',
-                'task_transition_id': 'task2__t0'
+                "route": 0,
+                "task_id": "task1",
+                "task_transition_id": "task2__t0",
             }
         ]
 
@@ -366,13 +357,13 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
         conductor.request_workflow_status(statuses.RUNNING)
 
         # The workflow should fail on completion of task1 while evaluating task transition.
-        self.forward_task_statuses(conductor, 'task1', [statuses.RUNNING, statuses.SUCCEEDED])
+        self.forward_task_statuses(conductor, "task1", [statuses.RUNNING, statuses.SUCCEEDED])
 
         # The workflow should fail with the expected errors.
         self.assertEqual(conductor.get_workflow_status(), statuses.FAILED)
-        actual_errors = sorted(conductor.errors, key=lambda x: x.get('task_id', None))
+        actual_errors = sorted(conductor.errors, key=lambda x: x.get("task_id", None))
         self.assertListEqual(actual_errors, expected_errors)
-        self.assertNotIn('task2', conductor.workflow_state.staged)
+        self.assertNotIn("task2", conductor.workflow_state.staged)
 
         # Since the workflow failed, there should be no next tasks returned.
         self.assert_next_task(conductor, has_next_task=False)
@@ -406,15 +397,15 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().y.value %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().y.value %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#value"'
                 ),
-                'route': 0,
-                'task_id': 'task1',
-                'task_transition_id': 'task2__t0'
+                "route": 0,
+                "task_id": "task1",
+                "task_transition_id": "task2__t0",
             }
         ]
 
@@ -425,13 +416,13 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
         conductor.request_workflow_status(statuses.RUNNING)
 
         # The workflow should fail on completion of task1 while evaluating task transition.
-        self.forward_task_statuses(conductor, 'task1', [statuses.RUNNING, statuses.SUCCEEDED])
+        self.forward_task_statuses(conductor, "task1", [statuses.RUNNING, statuses.SUCCEEDED])
 
         # The workflow should fail with the expected errors.
         self.assertEqual(conductor.get_workflow_status(), statuses.FAILED)
-        actual_errors = sorted(conductor.errors, key=lambda x: x.get('task_id', None))
+        actual_errors = sorted(conductor.errors, key=lambda x: x.get("task_id", None))
         self.assertListEqual(actual_errors, expected_errors)
-        self.assertNotIn('task2', conductor.workflow_state.staged)
+        self.assertNotIn("task2", conductor.workflow_state.staged)
 
         # Since the workflow failed, there should be no next tasks returned.
         self.assert_next_task(conductor, has_next_task=False)
@@ -457,14 +448,14 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().foobar.fubar %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().foobar.fubar %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#fubar"'
                 ),
-                'route': 0,
-                'task_id': 'task1'
+                "route": 0,
+                "task_id": "task1",
             }
         ]
 
@@ -479,7 +470,7 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         # The workflow should fail with the expected errors.
         self.assertEqual(conductor.get_workflow_status(), statuses.FAILED)
-        actual_errors = sorted(conductor.errors, key=lambda x: x.get('task_id', None))
+        actual_errors = sorted(conductor.errors, key=lambda x: x.get("task_id", None))
         self.assertListEqual(actual_errors, expected_errors)
 
     def test_get_start_tasks_via_get_next_tasks_with_task_action_error(self):
@@ -503,14 +494,14 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().foobar.fubar %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().foobar.fubar %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#fubar"'
                 ),
-                'route': 0,
-                'task_id': 'task1'
+                "route": 0,
+                "task_id": "task1",
             }
         ]
 
@@ -525,7 +516,7 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         # The workflow should fail with the expected errors.
         self.assertEqual(conductor.get_workflow_status(), statuses.FAILED)
-        actual_errors = sorted(conductor.errors, key=lambda x: x.get('task_id', None))
+        actual_errors = sorted(conductor.errors, key=lambda x: x.get("task_id", None))
         self.assertListEqual(actual_errors, expected_errors)
 
     def test_get_next_tasks_with_task_action_error(self):
@@ -549,14 +540,14 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().foobar.fubar %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().foobar.fubar %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#fubar"'
                 ),
-                'route': 0,
-                'task_id': 'task2'
+                "route": 0,
+                "task_id": "task2",
             }
         ]
 
@@ -567,14 +558,14 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
         conductor.request_workflow_status(statuses.RUNNING)
 
         # Manually complete task1.
-        self.forward_task_statuses(conductor, 'task1', [statuses.RUNNING, statuses.SUCCEEDED])
+        self.forward_task_statuses(conductor, "task1", [statuses.RUNNING, statuses.SUCCEEDED])
 
         # The get_next_tasks method should not return any tasks.
         self.assert_next_task(conductor, has_next_task=False)
 
         # The workflow should fail with the expected errors.
         self.assertEqual(conductor.get_workflow_status(), statuses.FAILED)
-        actual_errors = sorted(conductor.errors, key=lambda x: x.get('task_id', None))
+        actual_errors = sorted(conductor.errors, key=lambda x: x.get("task_id", None))
         self.assertListEqual(actual_errors, expected_errors)
 
     def test_get_start_tasks_with_task_input_error(self):
@@ -600,14 +591,14 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().foobar.fubar %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().foobar.fubar %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#fubar"'
                 ),
-                'route': 0,
-                'task_id': 'task1'
+                "route": 0,
+                "task_id": "task1",
             }
         ]
 
@@ -622,7 +613,7 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         # The workflow should fail with the expected errors.
         self.assertEqual(conductor.get_workflow_status(), statuses.FAILED)
-        actual_errors = sorted(conductor.errors, key=lambda x: x.get('task_id', None))
+        actual_errors = sorted(conductor.errors, key=lambda x: x.get("task_id", None))
         self.assertListEqual(actual_errors, expected_errors)
 
     def test_get_start_tasks_via_get_next_tasks_with_task_input_error(self):
@@ -648,14 +639,14 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().foobar.fubar %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().foobar.fubar %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#fubar"'
                 ),
-                'route': 0,
-                'task_id': 'task1'
+                "route": 0,
+                "task_id": "task1",
             }
         ]
 
@@ -670,7 +661,7 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         # The workflow should fail with the expected errors.
         self.assertEqual(conductor.get_workflow_status(), statuses.FAILED)
-        actual_errors = sorted(conductor.errors, key=lambda x: x.get('task_id', None))
+        actual_errors = sorted(conductor.errors, key=lambda x: x.get("task_id", None))
         self.assertListEqual(actual_errors, expected_errors)
 
     def test_get_next_tasks_with_task_input_error(self):
@@ -696,14 +687,14 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().foobar.fubar %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().foobar.fubar %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#fubar"'
                 ),
-                'route': 0,
-                'task_id': 'task2'
+                "route": 0,
+                "task_id": "task2",
             }
         ]
 
@@ -714,14 +705,14 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
         conductor.request_workflow_status(statuses.RUNNING)
 
         # Manually complete task1.
-        self.forward_task_statuses(conductor, 'task1', [statuses.RUNNING, statuses.SUCCEEDED])
+        self.forward_task_statuses(conductor, "task1", [statuses.RUNNING, statuses.SUCCEEDED])
 
         # The get_next_tasks method should not return any tasks.
         self.assert_next_task(conductor, has_next_task=False)
 
         # The workflow should fail with the expected errors.
         self.assertEqual(conductor.get_workflow_status(), statuses.FAILED)
-        actual_errors = sorted(conductor.errors, key=lambda x: x.get('task_id', None))
+        actual_errors = sorted(conductor.errors, key=lambda x: x.get("task_id", None))
         self.assertListEqual(actual_errors, expected_errors)
 
     def test_get_start_tasks_with_multiple_task_action_and_input_errors(self):
@@ -752,25 +743,25 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().foobar.fubar %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().foobar.fubar %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#fubar"'
                 ),
-                'route': 0,
-                'task_id': 'task1'
+                "route": 0,
+                "task_id": "task1",
             },
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().fubar.foobar %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().fubar.foobar %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#foobar"'
                 ),
-                'route': 0,
-                'task_id': 'task2'
-            }
+                "route": 0,
+                "task_id": "task2",
+            },
         ]
 
         spec = native_specs.WorkflowSpec(wf_def)
@@ -784,7 +775,7 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         # The workflow should fail with the expected errors.
         self.assertEqual(conductor.get_workflow_status(), statuses.FAILED)
-        actual_errors = sorted(conductor.errors, key=lambda x: x.get('task_id', None))
+        actual_errors = sorted(conductor.errors, key=lambda x: x.get("task_id", None))
         self.assertListEqual(actual_errors, expected_errors)
 
     def test_get_start_tasks_via_get_next_tasks_with_multiple_task_action_and_input_errors(self):
@@ -815,25 +806,25 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().foobar.fubar %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().foobar.fubar %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#fubar"'
                 ),
-                'route': 0,
-                'task_id': 'task1'
+                "route": 0,
+                "task_id": "task1",
             },
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().fubar.foobar %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().fubar.foobar %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#foobar"'
                 ),
-                'route': 0,
-                'task_id': 'task2'
-            }
+                "route": 0,
+                "task_id": "task2",
+            },
         ]
 
         spec = native_specs.WorkflowSpec(wf_def)
@@ -847,7 +838,7 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         # The workflow should fail with the expected errors.
         self.assertEqual(conductor.get_workflow_status(), statuses.FAILED)
-        actual_errors = sorted(conductor.errors, key=lambda x: x.get('task_id', None))
+        actual_errors = sorted(conductor.errors, key=lambda x: x.get("task_id", None))
         self.assertListEqual(actual_errors, expected_errors)
 
     def test_get_next_tasks_with_multiple_task_action_and_input_errors(self):
@@ -874,25 +865,25 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().foobar.fubar %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().foobar.fubar %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#fubar"'
                 ),
-                'route': 0,
-                'task_id': 'task2'
+                "route": 0,
+                "task_id": "task2",
             },
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().fubar.foobar %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().fubar.foobar %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#foobar"'
                 ),
-                'route': 0,
-                'task_id': 'task3'
-            }
+                "route": 0,
+                "task_id": "task3",
+            },
         ]
 
         spec = native_specs.WorkflowSpec(wf_def)
@@ -902,14 +893,14 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
         conductor.request_workflow_status(statuses.RUNNING)
 
         # Manually complete task1.
-        self.forward_task_statuses(conductor, 'task1', [statuses.RUNNING, statuses.SUCCEEDED])
+        self.forward_task_statuses(conductor, "task1", [statuses.RUNNING, statuses.SUCCEEDED])
 
         # The get_next_tasks method should not return any tasks.
         self.assert_next_task(conductor, has_next_task=False)
 
         # The workflow should fail with the expected errors.
         self.assertEqual(conductor.get_workflow_status(), statuses.FAILED)
-        actual_errors = sorted(conductor.errors, key=lambda x: x.get('task_id', None))
+        actual_errors = sorted(conductor.errors, key=lambda x: x.get("task_id", None))
         self.assertListEqual(actual_errors, expected_errors)
 
     def test_workflow_output_error(self):
@@ -926,12 +917,12 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% result().foobar %>\'. ExpressionEvaluationException: '
-                    'The current task is not set in the context.'
-                )
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% result().foobar %>'. ExpressionEvaluationException: "
+                    "The current task is not set in the context."
+                ),
             }
         ]
 
@@ -942,7 +933,7 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
         conductor.request_workflow_status(statuses.RUNNING)
 
         # Manually complete task1.
-        self.forward_task_statuses(conductor, 'task1', [statuses.RUNNING, statuses.SUCCEEDED])
+        self.forward_task_statuses(conductor, "task1", [statuses.RUNNING, statuses.SUCCEEDED])
 
         # Render workflow output and checkout workflow status and output.
         conductor.render_workflow_output()
@@ -964,19 +955,16 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
             action: core.noop
         """
 
-        expected_output = {
-            'x': 123,
-            'y': 123
-        }
+        expected_output = {"x": 123, "y": 123}
 
         expected_errors = [
             {
-                'type': 'error',
-                'message': (
-                    'YaqlEvaluationException: Unable to evaluate expression '
-                    '\'<% ctx().y.value %>\'. NoFunctionRegisteredException: '
+                "type": "error",
+                "message": (
+                    "YaqlEvaluationException: Unable to evaluate expression "
+                    "'<% ctx().y.value %>'. NoFunctionRegisteredException: "
                     'Unknown function "#property#value"'
-                )
+                ),
             }
         ]
 
@@ -987,7 +975,7 @@ class WorkflowConductorErrorHandlingTest(test_base.WorkflowConductorTest):
         conductor.request_workflow_status(statuses.RUNNING)
 
         # Manually complete task1.
-        self.forward_task_statuses(conductor, 'task1', [statuses.RUNNING, statuses.SUCCEEDED])
+        self.forward_task_statuses(conductor, "task1", [statuses.RUNNING, statuses.SUCCEEDED])
 
         # Render workflow output and checkout workflow status and output.
         conductor.render_workflow_output()
