@@ -19,7 +19,6 @@ from orquesta.tests.unit import base as test_base
 
 
 class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsTest):
-
     def test_cancel_item_list_processed(self):
         wf_def = """
         version: 1.0
@@ -51,35 +50,35 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
 
         # Mock the action execution for each item and assert expected task statuses.
         task_route = 0
-        task_name = 'task1'
-        task_ctx = {'xs': ['fee', 'fi', 'fo', 'fum']}
+        task_name = "task1"
+        task_ctx = {"xs": ["fee", "fi", "fo", "fum"]}
 
         task_action_specs = [
-            {'action': 'core.echo', 'input': {'message': 'fee'}, 'item_id': 0},
-            {'action': 'core.echo', 'input': {'message': 'fi'}, 'item_id': 1},
-            {'action': 'core.echo', 'input': {'message': 'fo'}, 'item_id': 2},
-            {'action': 'core.echo', 'input': {'message': 'fum'}, 'item_id': 3},
+            {"action": "core.echo", "input": {"message": "fee"}, "item_id": 0},
+            {"action": "core.echo", "input": {"message": "fi"}, "item_id": 1},
+            {"action": "core.echo", "input": {"message": "fo"}, "item_id": 2},
+            {"action": "core.echo", "input": {"message": "fum"}, "item_id": 3},
         ]
 
         mock_ac_ex_statuses = [
             statuses.SUCCEEDED,
             statuses.CANCELED,
             statuses.SUCCEEDED,
-            statuses.SUCCEEDED
+            statuses.SUCCEEDED,
         ]
 
         expected_task_statuses = [
             statuses.RUNNING,
             statuses.CANCELING,
             statuses.CANCELING,
-            statuses.CANCELED
+            statuses.CANCELED,
         ]
 
         expected_workflow_statuses = [
             statuses.RUNNING,
             statuses.CANCELING,
             statuses.CANCELING,
-            statuses.CANCELED
+            statuses.CANCELED,
         ]
 
         self.assert_task_items(
@@ -87,11 +86,11 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
             task_name,
             task_route,
             task_ctx,
-            task_ctx['xs'],
+            task_ctx["xs"],
             task_action_specs,
             mock_ac_ex_statuses,
             expected_task_statuses,
-            expected_workflow_statuses
+            expected_workflow_statuses,
         )
 
         # Assert the task is removed from staging.
@@ -131,14 +130,14 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
 
         # Mock the action execution for each item and assert expected task statuses.
         task_route = 0
-        task_name = 'task1'
-        task_ctx = {'xs': ['fee', 'fi', 'fo', 'fum']}
+        task_name = "task1"
+        task_ctx = {"xs": ["fee", "fi", "fo", "fum"]}
 
         task_action_specs = [
-            {'action': 'core.echo', 'input': {'message': 'fee'}, 'item_id': 0},
-            {'action': 'core.echo', 'input': {'message': 'fi'}, 'item_id': 1},
-            {'action': 'core.echo', 'input': {'message': 'fo'}, 'item_id': 2},
-            {'action': 'core.echo', 'input': {'message': 'fum'}, 'item_id': 3},
+            {"action": "core.echo", "input": {"message": "fee"}, "item_id": 0},
+            {"action": "core.echo", "input": {"message": "fi"}, "item_id": 1},
+            {"action": "core.echo", "input": {"message": "fo"}, "item_id": 2},
+            {"action": "core.echo", "input": {"message": "fum"}, "item_id": 3},
         ]
 
         mock_ac_ex_statuses = [statuses.SUCCEEDED, statuses.CANCELED, statuses.SUCCEEDED]
@@ -150,11 +149,11 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
             task_name,
             task_route,
             task_ctx,
-            task_ctx['xs'],
+            task_ctx["xs"],
             task_action_specs,
             mock_ac_ex_statuses,
             expected_task_statuses,
-            expected_workflow_statuses
+            expected_workflow_statuses,
         )
 
         # Assert the task is removed from staging.
@@ -194,14 +193,14 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
 
         # Mock the action execution for each item and assert expected task statuses.
         task_route = 0
-        task_name = 'task1'
-        task_ctx = {'xs': ['fee', 'fi', 'fo', 'fum']}
+        task_name = "task1"
+        task_ctx = {"xs": ["fee", "fi", "fo", "fum"]}
 
         task_action_specs = [
-            {'action': 'core.echo', 'input': {'message': 'fee'}, 'item_id': 0},
-            {'action': 'core.echo', 'input': {'message': 'fi'}, 'item_id': 1},
-            {'action': 'core.echo', 'input': {'message': 'fo'}, 'item_id': 2},
-            {'action': 'core.echo', 'input': {'message': 'fum'}, 'item_id': 3},
+            {"action": "core.echo", "input": {"message": "fee"}, "item_id": 0},
+            {"action": "core.echo", "input": {"message": "fi"}, "item_id": 1},
+            {"action": "core.echo", "input": {"message": "fo"}, "item_id": 2},
+            {"action": "core.echo", "input": {"message": "fum"}, "item_id": 3},
         ]
 
         # Verify the set of action executions.
@@ -211,7 +210,7 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
             task_ctx,
             conductor.spec.tasks.get_task(task_name),
             actions=task_action_specs,
-            items_count=len(task_ctx['xs'])
+            items_count=len(task_ctx["xs"]),
         )
 
         expected_tasks = [expected_task]
@@ -219,27 +218,27 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
         self.assert_task_list(conductor, actual_tasks, expected_tasks)
 
         # Set the items to running status.
-        for i in range(0, len(task_ctx['xs'])):
+        for i in range(0, len(task_ctx["xs"])):
             self.forward_task_item_statuses(conductor, task_name, i, [statuses.RUNNING])
 
         # Assert that the task is running.
-        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)['status']
+        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)["status"]
         self.assertEqual(actual_task_status, statuses.RUNNING)
 
         # Cancel the workflow.
         conductor.request_workflow_status(statuses.CANCELING)
         self.assertEqual(conductor.get_workflow_status(), statuses.CANCELING)
-        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)['status']
+        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)["status"]
         self.assertEqual(actual_task_status, statuses.CANCELING)
 
         # Complete the items.
-        for i in range(0, len(task_ctx['xs'])):
-            result = task_ctx['xs'][i]
+        for i in range(0, len(task_ctx["xs"])):
+            result = task_ctx["xs"][i]
             status_changes = [statuses.SUCCEEDED]
             self.forward_task_item_statuses(conductor, task_name, i, status_changes, result=result)
 
         # Assert the task is completed and workflow is canceled.
-        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)['status']
+        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)["status"]
         self.assertEqual(actual_task_status, statuses.SUCCEEDED)
         self.assertEqual(conductor.get_workflow_status(), statuses.CANCELED)
 
@@ -274,14 +273,14 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
 
         # Mock the action execution for each item and assert expected task statuses.
         task_route = 0
-        task_name = 'task1'
-        task_ctx = {'xs': ['fee', 'fi', 'fo', 'fum']}
+        task_name = "task1"
+        task_ctx = {"xs": ["fee", "fi", "fo", "fum"]}
 
         task_action_specs = [
-            {'action': 'core.echo', 'input': {'message': 'fee'}, 'item_id': 0},
-            {'action': 'core.echo', 'input': {'message': 'fi'}, 'item_id': 1},
-            {'action': 'core.echo', 'input': {'message': 'fo'}, 'item_id': 2},
-            {'action': 'core.echo', 'input': {'message': 'fum'}, 'item_id': 3},
+            {"action": "core.echo", "input": {"message": "fee"}, "item_id": 0},
+            {"action": "core.echo", "input": {"message": "fi"}, "item_id": 1},
+            {"action": "core.echo", "input": {"message": "fo"}, "item_id": 2},
+            {"action": "core.echo", "input": {"message": "fum"}, "item_id": 3},
         ]
 
         # Verify the set of action executions.
@@ -291,7 +290,7 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
             task_ctx,
             conductor.spec.tasks.get_task(task_name),
             actions=task_action_specs,
-            items_count=len(task_ctx['xs'])
+            items_count=len(task_ctx["xs"]),
         )
 
         expected_tasks = [expected_task]
@@ -299,27 +298,27 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
         self.assert_task_list(conductor, actual_tasks, expected_tasks)
 
         # Set the items to running status.
-        for i in range(0, len(task_ctx['xs'])):
+        for i in range(0, len(task_ctx["xs"])):
             self.forward_task_item_statuses(conductor, task_name, i, [statuses.RUNNING])
 
         # Assert that the task is running.
-        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)['status']
+        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)["status"]
         self.assertEqual(actual_task_status, statuses.RUNNING)
 
         # Cancel the workflow.
         conductor.request_workflow_status(statuses.CANCELED)
         self.assertEqual(conductor.get_workflow_status(), statuses.CANCELING)
-        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)['status']
+        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)["status"]
         self.assertEqual(actual_task_status, statuses.CANCELING)
 
         # Complete the items.
-        for i in range(0, len(task_ctx['xs'])):
-            result = task_ctx['xs'][i]
+        for i in range(0, len(task_ctx["xs"])):
+            result = task_ctx["xs"][i]
             status_changes = [statuses.SUCCEEDED]
             self.forward_task_item_statuses(conductor, task_name, i, status_changes, result=result)
 
         # Assert the task is completed and workflow is canceled.
-        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)['status']
+        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)["status"]
         self.assertEqual(actual_task_status, statuses.SUCCEEDED)
         self.assertEqual(conductor.get_workflow_status(), statuses.CANCELED)
 
@@ -358,14 +357,14 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
 
         # Mock the action execution for each item and assert expected task statuses.
         task_route = 0
-        task_name = 'task1'
-        task_ctx = {'xs': ['fee', 'fi', 'fo', 'fum']}
+        task_name = "task1"
+        task_ctx = {"xs": ["fee", "fi", "fo", "fum"]}
 
         task_action_specs = [
-            {'action': 'core.echo', 'input': {'message': 'fee'}, 'item_id': 0},
-            {'action': 'core.echo', 'input': {'message': 'fi'}, 'item_id': 1},
-            {'action': 'core.echo', 'input': {'message': 'fo'}, 'item_id': 2},
-            {'action': 'core.echo', 'input': {'message': 'fum'}, 'item_id': 3},
+            {"action": "core.echo", "input": {"message": "fee"}, "item_id": 0},
+            {"action": "core.echo", "input": {"message": "fi"}, "item_id": 1},
+            {"action": "core.echo", "input": {"message": "fo"}, "item_id": 2},
+            {"action": "core.echo", "input": {"message": "fum"}, "item_id": 3},
         ]
 
         mock_ac_ex_statuses = [statuses.SUCCEEDED] * 2
@@ -377,12 +376,12 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
             task_name,
             task_route,
             task_ctx,
-            task_ctx['xs'],
+            task_ctx["xs"],
             task_action_specs,
             mock_ac_ex_statuses,
             expected_task_statuses,
             expected_workflow_statuses,
-            concurrency=concurrency
+            concurrency=concurrency,
         )
 
         # Assert the task is not removed from staging.
@@ -394,7 +393,7 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
         # Cancel the workflow.
         conductor.request_workflow_status(statuses.CANCELING)
         self.assertEqual(conductor.get_workflow_status(), statuses.CANCELED)
-        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)['status']
+        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)["status"]
         self.assertEqual(actual_task_status, statuses.CANCELED)
 
     def test_cancel_workflow_using_canceled_status_with_items_concurrency(self):
@@ -432,14 +431,14 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
 
         # Mock the action execution for each item and assert expected task statuses.
         task_route = 0
-        task_name = 'task1'
-        task_ctx = {'xs': ['fee', 'fi', 'fo', 'fum']}
+        task_name = "task1"
+        task_ctx = {"xs": ["fee", "fi", "fo", "fum"]}
 
         task_action_specs = [
-            {'action': 'core.echo', 'input': {'message': 'fee'}, 'item_id': 0},
-            {'action': 'core.echo', 'input': {'message': 'fi'}, 'item_id': 1},
-            {'action': 'core.echo', 'input': {'message': 'fo'}, 'item_id': 2},
-            {'action': 'core.echo', 'input': {'message': 'fum'}, 'item_id': 3},
+            {"action": "core.echo", "input": {"message": "fee"}, "item_id": 0},
+            {"action": "core.echo", "input": {"message": "fi"}, "item_id": 1},
+            {"action": "core.echo", "input": {"message": "fo"}, "item_id": 2},
+            {"action": "core.echo", "input": {"message": "fum"}, "item_id": 3},
         ]
 
         mock_ac_ex_statuses = [statuses.SUCCEEDED] * 2
@@ -451,12 +450,12 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
             task_name,
             task_route,
             task_ctx,
-            task_ctx['xs'],
+            task_ctx["xs"],
             task_action_specs,
             mock_ac_ex_statuses,
             expected_task_statuses,
             expected_workflow_statuses,
-            concurrency=concurrency
+            concurrency=concurrency,
         )
 
         # Assert the task is not removed from staging.
@@ -468,7 +467,7 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
         # Cancel the workflow.
         conductor.request_workflow_status(statuses.CANCELED)
         self.assertEqual(conductor.get_workflow_status(), statuses.CANCELED)
-        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)['status']
+        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)["status"]
         self.assertEqual(actual_task_status, statuses.CANCELED)
 
     def test_cancel_workflow_with_items_concurrency_and_active(self):
@@ -506,14 +505,14 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
 
         # Mock the action execution for each item and assert expected task statuses.
         task_route = 0
-        task_name = 'task1'
-        task_ctx = {'xs': ['fee', 'fi', 'fo', 'fum']}
+        task_name = "task1"
+        task_ctx = {"xs": ["fee", "fi", "fo", "fum"]}
 
         task_action_specs = [
-            {'action': 'core.echo', 'input': {'message': 'fee'}, 'item_id': 0},
-            {'action': 'core.echo', 'input': {'message': 'fi'}, 'item_id': 1},
-            {'action': 'core.echo', 'input': {'message': 'fo'}, 'item_id': 2},
-            {'action': 'core.echo', 'input': {'message': 'fum'}, 'item_id': 3},
+            {"action": "core.echo", "input": {"message": "fee"}, "item_id": 0},
+            {"action": "core.echo", "input": {"message": "fi"}, "item_id": 1},
+            {"action": "core.echo", "input": {"message": "fo"}, "item_id": 2},
+            {"action": "core.echo", "input": {"message": "fum"}, "item_id": 3},
         ]
 
         # Verify the first set of action executions.
@@ -523,8 +522,8 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
             task_ctx,
             conductor.spec.tasks.get_task(task_name),
             actions=task_action_specs[0:concurrency],
-            items_count=len(task_ctx['xs']),
-            items_concurrency=concurrency
+            items_count=len(task_ctx["xs"]),
+            items_concurrency=concurrency,
         )
 
         expected_tasks = [expected_task]
@@ -536,22 +535,22 @@ class WorkflowConductorWithItemsCancelTest(test_base.WorkflowConductorWithItemsT
             self.forward_task_item_statuses(conductor, task_name, i, [statuses.RUNNING])
 
         # Assert that the task is running.
-        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)['status']
+        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)["status"]
         self.assertEqual(actual_task_status, statuses.RUNNING)
 
         # Cancel the workflow.
         conductor.request_workflow_status(statuses.CANCELING)
         self.assertEqual(conductor.get_workflow_status(), statuses.CANCELING)
-        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)['status']
+        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)["status"]
         self.assertEqual(actual_task_status, statuses.CANCELING)
 
         # Complete the items.
         for i in range(0, concurrency):
-            result = task_ctx['xs'][i]
+            result = task_ctx["xs"][i]
             status_changes = [statuses.SUCCEEDED]
             self.forward_task_item_statuses(conductor, task_name, i, status_changes, result=result)
 
         # Assert the task and workflow are canceled.
-        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)['status']
+        actual_task_status = conductor.workflow_state.get_task(task_name, task_route)["status"]
         self.assertEqual(actual_task_status, statuses.CANCELED)
         self.assertEqual(conductor.get_workflow_status(), statuses.CANCELED)
