@@ -18,27 +18,23 @@ from orquesta.tests.unit.conducting.native import base
 
 
 class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
-
     def __init__(self, *args, **kwargs):
         super(SequentialWorkflowStatusTest, self).__init__(*args, **kwargs)
-        self.wf_name = 'sequential'
+        self.wf_name = "sequential"
 
     def assert_workflow_status(self, mock_flow_entries, expected_wf_statuses, conductor=None):
         return super(SequentialWorkflowStatusTest, self).assert_workflow_status(
-            self.wf_name,
-            mock_flow_entries,
-            expected_wf_statuses,
-            conductor=conductor
+            self.wf_name, mock_flow_entries, expected_wf_statuses, conductor=conductor
         )
 
     def test_success(self):
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.SUCCEEDED},
-            {'id': 'task3', 'name': 'task3', 'status': statuses.RUNNING},
-            {'id': 'task3', 'name': 'task3', 'status': statuses.SUCCEEDED}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
+            {"id": "task2", "name": "task2", "status": statuses.SUCCEEDED},
+            {"id": "task3", "name": "task3", "status": statuses.RUNNING},
+            {"id": "task3", "name": "task3", "status": statuses.SUCCEEDED},
         ]
 
         expected_wf_statuses = [
@@ -47,41 +43,41 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
             statuses.RUNNING,
             statuses.RUNNING,
             statuses.RUNNING,
-            statuses.SUCCEEDED
+            statuses.SUCCEEDED,
         ]
 
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
 
     def test_failure(self):
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.FAILED}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
+            {"id": "task2", "name": "task2", "status": statuses.FAILED},
         ]
 
         expected_wf_statuses = [
             statuses.RUNNING,
             statuses.RUNNING,
             statuses.RUNNING,
-            statuses.FAILED
+            statuses.FAILED,
         ]
 
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
 
     def test_pending(self):
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.PENDING}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
+            {"id": "task2", "name": "task2", "status": statuses.PENDING},
         ]
 
         expected_wf_statuses = [
             statuses.RUNNING,
             statuses.RUNNING,
             statuses.RUNNING,
-            statuses.PAUSED
+            statuses.PAUSED,
         ]
 
         # Assert statuses and then save the conductor for later.
@@ -91,16 +87,12 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
         conductor.request_workflow_status(statuses.RESUMING)
 
         mock_flow_entries = [
-            {'id': 'task2', 'name': 'task2', 'status': statuses.SUCCEEDED},
-            {'id': 'task3', 'name': 'task3', 'status': statuses.RUNNING},
-            {'id': 'task3', 'name': 'task3', 'status': statuses.SUCCEEDED}
+            {"id": "task2", "name": "task2", "status": statuses.SUCCEEDED},
+            {"id": "task3", "name": "task3", "status": statuses.RUNNING},
+            {"id": "task3", "name": "task3", "status": statuses.SUCCEEDED},
         ]
 
-        expected_wf_statuses = [
-            statuses.RUNNING,
-            statuses.RUNNING,
-            statuses.SUCCEEDED
-        ]
+        expected_wf_statuses = [statuses.RUNNING, statuses.RUNNING, statuses.SUCCEEDED]
 
         # Assert the remaining statuses using the previous conductor.
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses, conductor=conductor)
@@ -108,16 +100,12 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
     def test_workflow_pausing_while_task_running(self):
         # Run workflow until task2 is running.
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
         ]
 
-        expected_wf_statuses = [
-            statuses.RUNNING,
-            statuses.RUNNING,
-            statuses.RUNNING
-        ]
+        expected_wf_statuses = [statuses.RUNNING, statuses.RUNNING, statuses.RUNNING]
 
         # Assert statuses and then save the conductor for later.
         conductor = self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
@@ -125,13 +113,9 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
         # Pause the workflow and assert the remaining statuses.
         conductor.request_workflow_status(statuses.PAUSING)
 
-        mock_flow_entries = [
-            {'id': 'task2', 'name': 'task2', 'status': statuses.SUCCEEDED}
-        ]
+        mock_flow_entries = [{"id": "task2", "name": "task2", "status": statuses.SUCCEEDED}]
 
-        expected_wf_statuses = [
-            statuses.PAUSED
-        ]
+        expected_wf_statuses = [statuses.PAUSED]
 
         # Assert the remaining statuses using the previous conductor.
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses, conductor=conductor)
@@ -139,16 +123,12 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
     def test_workflow_pausing_and_resuming_while_task_running(self):
         # Run workflow until task2 is running.
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
         ]
 
-        expected_wf_statuses = [
-            statuses.RUNNING,
-            statuses.RUNNING,
-            statuses.RUNNING
-        ]
+        expected_wf_statuses = [statuses.RUNNING, statuses.RUNNING, statuses.RUNNING]
 
         # Assert statuses and then save the conductor for later.
         conductor = self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
@@ -157,13 +137,9 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
         conductor.request_workflow_status(statuses.PAUSING)
         conductor.request_workflow_status(statuses.RESUMING)
 
-        mock_flow_entries = [
-            {'id': 'task2', 'name': 'task2', 'status': statuses.SUCCEEDED}
-        ]
+        mock_flow_entries = [{"id": "task2", "name": "task2", "status": statuses.SUCCEEDED}]
 
-        expected_wf_statuses = [
-            statuses.RUNNING
-        ]
+        expected_wf_statuses = [statuses.RUNNING]
 
         # Assert the remaining statuses using the previous conductor.
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses, conductor=conductor)
@@ -171,16 +147,12 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
     def test_workflow_pausing_then_task_abended(self):
         # Run workflow until task2 is running.
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
         ]
 
-        expected_wf_statuses = [
-            statuses.RUNNING,
-            statuses.RUNNING,
-            statuses.RUNNING
-        ]
+        expected_wf_statuses = [statuses.RUNNING, statuses.RUNNING, statuses.RUNNING]
 
         # Assert statuses and then save the conductor for later.
         conductor = self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
@@ -188,13 +160,9 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
         # Pause the workflow and assert the remaining statuses.
         conductor.request_workflow_status(statuses.PAUSING)
 
-        mock_flow_entries = [
-            {'id': 'task2', 'name': 'task2', 'status': statuses.FAILED}
-        ]
+        mock_flow_entries = [{"id": "task2", "name": "task2", "status": statuses.FAILED}]
 
-        expected_wf_statuses = [
-            statuses.FAILED
-        ]
+        expected_wf_statuses = [statuses.FAILED]
 
         # Assert the remaining statuses using the previous conductor.
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses, conductor=conductor)
@@ -202,16 +170,12 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
     def test_workflow_pausing_then_task_canceled(self):
         # Run workflow until task2 is running.
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
         ]
 
-        expected_wf_statuses = [
-            statuses.RUNNING,
-            statuses.RUNNING,
-            statuses.RUNNING
-        ]
+        expected_wf_statuses = [statuses.RUNNING, statuses.RUNNING, statuses.RUNNING]
 
         # Assert statuses and then save the conductor for later.
         conductor = self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
@@ -219,13 +183,9 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
         # Pause the workflow and assert the remaining statuses.
         conductor.request_workflow_status(statuses.PAUSING)
 
-        mock_flow_entries = [
-            {'id': 'task2', 'name': 'task2', 'status': statuses.CANCELED}
-        ]
+        mock_flow_entries = [{"id": "task2", "name": "task2", "status": statuses.CANCELED}]
 
-        expected_wf_statuses = [
-            statuses.CANCELED
-        ]
+        expected_wf_statuses = [statuses.CANCELED]
 
         # Assert the remaining statuses using the previous conductor.
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses, conductor=conductor)
@@ -233,16 +193,12 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
     def test_workflow_pausing_then_task_pending(self):
         # Run workflow until task2 is running.
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
         ]
 
-        expected_wf_statuses = [
-            statuses.RUNNING,
-            statuses.RUNNING,
-            statuses.RUNNING
-        ]
+        expected_wf_statuses = [statuses.RUNNING, statuses.RUNNING, statuses.RUNNING]
 
         # Assert statuses and then save the conductor for later.
         conductor = self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
@@ -250,13 +206,9 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
         # Pause the workflow and assert the remaining statuses.
         conductor.request_workflow_status(statuses.PAUSING)
 
-        mock_flow_entries = [
-            {'id': 'task2', 'name': 'task2', 'status': statuses.PENDING}
-        ]
+        mock_flow_entries = [{"id": "task2", "name": "task2", "status": statuses.PENDING}]
 
-        expected_wf_statuses = [
-            statuses.PAUSED
-        ]
+        expected_wf_statuses = [statuses.PAUSED]
 
         # Assert the remaining statuses using the previous conductor.
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses, conductor=conductor)
@@ -264,16 +216,12 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
     def test_workflow_resuming(self):
         # Run workflow until task2 is running.
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
         ]
 
-        expected_wf_statuses = [
-            statuses.RUNNING,
-            statuses.RUNNING,
-            statuses.RUNNING
-        ]
+        expected_wf_statuses = [statuses.RUNNING, statuses.RUNNING, statuses.RUNNING]
 
         # Assert statuses and then save the conductor for later.
         conductor = self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
@@ -281,13 +229,9 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
         # Pause the workflow and assert the remaining statuses.
         conductor.request_workflow_status(statuses.PAUSING)
 
-        mock_flow_entries = [
-            {'id': 'task2', 'name': 'task2', 'status': statuses.SUCCEEDED}
-        ]
+        mock_flow_entries = [{"id": "task2", "name": "task2", "status": statuses.SUCCEEDED}]
 
-        expected_wf_statuses = [
-            statuses.PAUSED
-        ]
+        expected_wf_statuses = [statuses.PAUSED]
 
         # Assert the remaining statuses using the previous conductor.
         conductor = self.assert_workflow_status(mock_flow_entries, expected_wf_statuses, conductor)
@@ -296,14 +240,11 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
         conductor.request_workflow_status(statuses.RESUMING)
 
         mock_flow_entries = [
-            {'id': 'task3', 'name': 'task3', 'status': statuses.RUNNING},
-            {'id': 'task3', 'name': 'task3', 'status': statuses.SUCCEEDED}
+            {"id": "task3", "name": "task3", "status": statuses.RUNNING},
+            {"id": "task3", "name": "task3", "status": statuses.SUCCEEDED},
         ]
 
-        expected_wf_statuses = [
-            statuses.RUNNING,
-            statuses.SUCCEEDED
-        ]
+        expected_wf_statuses = [statuses.RUNNING, statuses.SUCCEEDED]
 
         # Assert the remaining statuses using the previous conductor.
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses, conductor=conductor)
@@ -311,16 +252,12 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
     def test_workflow_resuming_then_task_abended(self):
         # Run workflow until task2 is running.
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
         ]
 
-        expected_wf_statuses = [
-            statuses.RUNNING,
-            statuses.RUNNING,
-            statuses.RUNNING
-        ]
+        expected_wf_statuses = [statuses.RUNNING, statuses.RUNNING, statuses.RUNNING]
 
         # Assert statuses and then save the conductor for later.
         conductor = self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
@@ -328,13 +265,9 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
         # Pause the workflow and assert the remaining statuses.
         conductor.request_workflow_status(statuses.PAUSING)
 
-        mock_flow_entries = [
-            {'id': 'task2', 'name': 'task2', 'status': statuses.SUCCEEDED}
-        ]
+        mock_flow_entries = [{"id": "task2", "name": "task2", "status": statuses.SUCCEEDED}]
 
-        expected_wf_statuses = [
-            statuses.PAUSED
-        ]
+        expected_wf_statuses = [statuses.PAUSED]
 
         # Assert the remaining statuses using the previous conductor.
         conductor = self.assert_workflow_status(mock_flow_entries, expected_wf_statuses, conductor)
@@ -343,14 +276,11 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
         conductor.request_workflow_status(statuses.RESUMING)
 
         mock_flow_entries = [
-            {'id': 'task3', 'name': 'task3', 'status': statuses.RUNNING},
-            {'id': 'task3', 'name': 'task3', 'status': statuses.FAILED}
+            {"id": "task3", "name": "task3", "status": statuses.RUNNING},
+            {"id": "task3", "name": "task3", "status": statuses.FAILED},
         ]
 
-        expected_wf_statuses = [
-            statuses.RUNNING,
-            statuses.FAILED
-        ]
+        expected_wf_statuses = [statuses.RUNNING, statuses.FAILED]
 
         # Assert the remaining statuses using the previous conductor.
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses, conductor=conductor)
@@ -358,16 +288,12 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
     def test_workflow_resuming_then_task_canceled(self):
         # Run workflow until task2 is running.
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
         ]
 
-        expected_wf_statuses = [
-            statuses.RUNNING,
-            statuses.RUNNING,
-            statuses.RUNNING
-        ]
+        expected_wf_statuses = [statuses.RUNNING, statuses.RUNNING, statuses.RUNNING]
 
         # Assert statuses and then save the conductor for later.
         conductor = self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
@@ -375,13 +301,9 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
         # Pause the workflow and assert the remaining statuses.
         conductor.request_workflow_status(statuses.PAUSING)
 
-        mock_flow_entries = [
-            {'id': 'task2', 'name': 'task2', 'status': statuses.SUCCEEDED}
-        ]
+        mock_flow_entries = [{"id": "task2", "name": "task2", "status": statuses.SUCCEEDED}]
 
-        expected_wf_statuses = [
-            statuses.PAUSED
-        ]
+        expected_wf_statuses = [statuses.PAUSED]
 
         # Assert the remaining statuses using the previous conductor.
         conductor = self.assert_workflow_status(mock_flow_entries, expected_wf_statuses, conductor)
@@ -390,14 +312,11 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
         conductor.request_workflow_status(statuses.RESUMING)
 
         mock_flow_entries = [
-            {'id': 'task3', 'name': 'task3', 'status': statuses.RUNNING},
-            {'id': 'task3', 'name': 'task3', 'status': statuses.CANCELED}
+            {"id": "task3", "name": "task3", "status": statuses.RUNNING},
+            {"id": "task3", "name": "task3", "status": statuses.CANCELED},
         ]
 
-        expected_wf_statuses = [
-            statuses.RUNNING,
-            statuses.CANCELED
-        ]
+        expected_wf_statuses = [statuses.RUNNING, statuses.CANCELED]
 
         # Assert the remaining statuses using the previous conductor.
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses, conductor=conductor)
@@ -405,11 +324,11 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
     def test_task_pause(self):
         # Test use case where a task is paused.
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.PAUSING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.PAUSED}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
+            {"id": "task2", "name": "task2", "status": statuses.PAUSING},
+            {"id": "task2", "name": "task2", "status": statuses.PAUSED},
         ]
 
         expected_wf_statuses = [
@@ -417,7 +336,7 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
             statuses.RUNNING,
             statuses.RUNNING,
             statuses.RUNNING,
-            statuses.PAUSED
+            statuses.PAUSED,
         ]
 
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
@@ -425,12 +344,12 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
     def test_task_pausing_then_canceled(self):
         # Test use case where a task is pausing and then canceled.
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.PAUSING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.CANCELING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.CANCELED}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
+            {"id": "task2", "name": "task2", "status": statuses.PAUSING},
+            {"id": "task2", "name": "task2", "status": statuses.CANCELING},
+            {"id": "task2", "name": "task2", "status": statuses.CANCELED},
         ]
 
         expected_wf_statuses = [
@@ -439,7 +358,7 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
             statuses.RUNNING,
             statuses.RUNNING,
             statuses.CANCELING,
-            statuses.CANCELED
+            statuses.CANCELED,
         ]
 
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
@@ -447,11 +366,11 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
     def test_task_pausing_then_abended(self):
         # Test use case where a task is pausing and then failed.
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.PAUSING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.FAILED}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
+            {"id": "task2", "name": "task2", "status": statuses.PAUSING},
+            {"id": "task2", "name": "task2", "status": statuses.FAILED},
         ]
 
         expected_wf_statuses = [
@@ -459,7 +378,7 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
             statuses.RUNNING,
             statuses.RUNNING,
             statuses.RUNNING,
-            statuses.FAILED
+            statuses.FAILED,
         ]
 
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
@@ -467,16 +386,16 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
     def test_task_resume(self):
         # Test use case where a task is paused and resumed.
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.PAUSING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.PAUSED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RESUMING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.SUCCEEDED},
-            {'id': 'task3', 'name': 'task3', 'status': statuses.RUNNING},
-            {'id': 'task3', 'name': 'task3', 'status': statuses.SUCCEEDED}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
+            {"id": "task2", "name": "task2", "status": statuses.PAUSING},
+            {"id": "task2", "name": "task2", "status": statuses.PAUSED},
+            {"id": "task2", "name": "task2", "status": statuses.RESUMING},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
+            {"id": "task2", "name": "task2", "status": statuses.SUCCEEDED},
+            {"id": "task3", "name": "task3", "status": statuses.RUNNING},
+            {"id": "task3", "name": "task3", "status": statuses.SUCCEEDED},
         ]
 
         expected_wf_statuses = [
@@ -489,7 +408,7 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
             statuses.RUNNING,
             statuses.RUNNING,
             statuses.RUNNING,
-            statuses.SUCCEEDED
+            statuses.SUCCEEDED,
         ]
 
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
@@ -497,14 +416,14 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
     def test_task_resuming_then_canceled(self):
         # Test use case where a task is paused and resumed.
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.PAUSING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.PAUSED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RESUMING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.CANCELING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.CANCELED}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
+            {"id": "task2", "name": "task2", "status": statuses.PAUSING},
+            {"id": "task2", "name": "task2", "status": statuses.PAUSED},
+            {"id": "task2", "name": "task2", "status": statuses.RESUMING},
+            {"id": "task2", "name": "task2", "status": statuses.CANCELING},
+            {"id": "task2", "name": "task2", "status": statuses.CANCELED},
         ]
 
         expected_wf_statuses = [
@@ -515,7 +434,7 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
             statuses.PAUSED,
             statuses.RUNNING,
             statuses.CANCELING,
-            statuses.CANCELED
+            statuses.CANCELED,
         ]
 
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
@@ -523,11 +442,11 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
     def test_task_cancel(self):
         # Test use case where a task is canceled.
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.CANCELING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.CANCELED}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
+            {"id": "task2", "name": "task2", "status": statuses.CANCELING},
+            {"id": "task2", "name": "task2", "status": statuses.CANCELED},
         ]
 
         expected_wf_statuses = [
@@ -535,7 +454,7 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
             statuses.RUNNING,
             statuses.RUNNING,
             statuses.CANCELING,
-            statuses.CANCELED
+            statuses.CANCELED,
         ]
 
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
@@ -543,13 +462,13 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
     def test_task_canceling_then_paused(self):
         # Test use case where a task is canceling and then paused.
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.CANCELING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.PAUSING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.PAUSED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.CANCELED}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
+            {"id": "task2", "name": "task2", "status": statuses.CANCELING},
+            {"id": "task2", "name": "task2", "status": statuses.PAUSING},
+            {"id": "task2", "name": "task2", "status": statuses.PAUSED},
+            {"id": "task2", "name": "task2", "status": statuses.CANCELED},
         ]
 
         expected_wf_statuses = [
@@ -559,7 +478,7 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
             statuses.CANCELING,
             statuses.CANCELING,
             statuses.CANCELED,
-            statuses.CANCELED
+            statuses.CANCELED,
         ]
 
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
@@ -567,11 +486,11 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
     def test_task_canceling_then_abended(self):
         # Test use case where a task is pausing and then failed.
         mock_flow_entries = [
-            {'id': 'task1', 'name': 'task1', 'status': statuses.RUNNING},
-            {'id': 'task1', 'name': 'task1', 'status': statuses.SUCCEEDED},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.RUNNING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.CANCELING},
-            {'id': 'task2', 'name': 'task2', 'status': statuses.FAILED}
+            {"id": "task1", "name": "task1", "status": statuses.RUNNING},
+            {"id": "task1", "name": "task1", "status": statuses.SUCCEEDED},
+            {"id": "task2", "name": "task2", "status": statuses.RUNNING},
+            {"id": "task2", "name": "task2", "status": statuses.CANCELING},
+            {"id": "task2", "name": "task2", "status": statuses.FAILED},
         ]
 
         expected_wf_statuses = [
@@ -579,7 +498,7 @@ class SequentialWorkflowStatusTest(base.OrchestraWorkflowConductorTest):
             statuses.RUNNING,
             statuses.RUNNING,
             statuses.CANCELING,
-            statuses.CANCELED
+            statuses.CANCELED,
         ]
 
         self.assert_workflow_status(mock_flow_entries, expected_wf_statuses)
