@@ -24,14 +24,9 @@ LOG = logging.getLogger(__name__)
 
 def get_module(namespace, name):
     try:
-        mgr = driver.DriverManager(
-            namespace=namespace,
-            name=name,
-            invoke_on_load=False
-        )
+        mgr = driver.DriverManager(namespace=namespace, name=name, invoke_on_load=False)
     except RuntimeError as e:
-        raise exc.PluginFactoryError(
-            'Unable to load plugin %s.%s. %s' % (namespace, name, str(e)))
+        raise exc.PluginFactoryError("Unable to load plugin %s.%s. %s" % (namespace, name, str(e)))
 
     return mgr.driver
 
@@ -43,10 +38,9 @@ def get_instance(namespace, name, *args, **kwargs):
             name=name,
             invoke_on_load=True,
             invoke_args=args,
-            invoke_kwds=kwargs
+            invoke_kwds=kwargs,
         )
     except RuntimeError as e:
-        raise exc.PluginFactoryError(
-            'Unable to load plugin %s.%s. %s' % (namespace, name, str(e)))
+        raise exc.PluginFactoryError("Unable to load plugin %s.%s. %s" % (namespace, name, str(e)))
 
     return mgr.driver
