@@ -18,28 +18,28 @@ import chardet
 import six
 
 if six.PY2:
-    import __builtin__
+    import __builtin__  # pylint: disable=import-error
 
 
 LOG = logging.getLogger(__name__)
 
 
 def unescape(s):
-    return s.decode('string_escape') if six.PY2 else bytes(s, 'utf-8').decode('unicode_escape')
+    return s.decode("string_escape") if six.PY2 else bytes(s, "utf-8").decode("unicode_escape")
 
 
 def encoding(s):
-    return chardet.detect(s)['encoding']
+    return chardet.detect(s)["encoding"]
 
 
-def unicode(s, force=False):
+def unicode(s, force=False, encoding_type=None):
     if not isinstance(s, six.string_types) and not force:
         return s
 
     if six.PY2:
-        if not force and (isinstance(s, __builtin__.unicode) or encoding(s) == 'utf-8'):
+        if not force and (isinstance(s, __builtin__.unicode) or encoding(s) == "utf-8"):
             return s
 
-        return __builtin__.unicode(s)
+        return __builtin__.unicode(s, encoding_type) if encoding_type else __builtin__.unicode(s)
 
     return str(s)
